chi

package
v0.0.0-...-0a1c337 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 20, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Middleware

func Middleware(cfg ...Config) func(http.Handler) http.Handler

Middleware adapts the net/http middleware and enriches route from chi route context.

func MiddlewareWithConfig

func MiddlewareWithConfig(cfg Config) func(http.Handler) http.Handler

MiddlewareWithConfig adapts net/http middleware and enriches route from chi route context.

Types

type Config

type Config = nethttp.Config

Config mirrors net/http middleware configuration.

Jump to