echo

package
v0.0.0-...-0a1c337 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 20, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Middleware

func Middleware(cfg ...Config) echopkg.MiddlewareFunc

Middleware starts and emits canonical events for echo handlers.

func MiddlewareWithConfig

func MiddlewareWithConfig(cfg Config) echopkg.MiddlewareFunc

MiddlewareWithConfig starts and emits canonical events for echo handlers.

Types

type Config

type Config struct {
	Event string
}

Config controls echo middleware behavior.

Jump to