fiber

package
v0.0.0-...-0a1c337 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 20, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Middleware

func Middleware(cfg ...Config) fiberpkg.Handler

Middleware starts and emits canonical events for fiber handlers.

func MiddlewareWithConfig

func MiddlewareWithConfig(cfg Config) fiberpkg.Handler

MiddlewareWithConfig starts and emits canonical events for fiber handlers.

Types

type Config

type Config struct {
	Event string
}

Config controls fiber middleware behavior.

Jump to